<?php
/**
 * @package Sevu
 * @version 1.2.0
 */

/*
Plugin Name: ScaleEngine Virtual Usher
Plugin URI: http://sevu.scaleengine.net/
Description: Embeds video player using the ScaleEngine Virtual Usher system
Author: ScaleEngine
Version: 1.2.0
Author URI: https://www.scaleengine.com/
*/
/*
function sevuStartSession() {
    if(!session_id()) {
        session_start();
    }
}
add_action('init', 'sevuStartSession');

*/

add_action('init', 'myStartSession', 1);
add_action('wp_logout', 'myEndSession');
add_action('wp_login', 'myEndSession');

function myStartSession() {
    if(!session_id()) {
        session_start();
    }
}

function myEndSession() {
    session_destroy ();
}

$plugin_dir = plugin_dir_path(__FILE__);
include_once($plugin_dir.'sevu_options.php');
include_once($plugin_dir.'sevu_api.class.php');


/**
 *  Adds the SEVU video player embed code
 *
 *  @param
 *  
 */
function sevu_add_embed($atts)
{
    extract(shortcode_atts(array(
            'user' => '',
            'video' => '',
            'app_name' => '',
            'app_inst' => 'play',
            'height' => '400',
            'width' => '720',
            'autostart' => 'false',
            'js_player' => '',
            'player' => 'jwplayer',
            'playlist' => '',
            'rtmp' => '',
            'rtsp' => '',
            'swf' => '',
            'ip_restrict' => true,
            'num_uses' => 99,
            'expire' => null,
            'jw_version' => '7',
            'smil' => '',
        ),$atts)
    );
    
    $embed_base_url = "embed.scaleengine.net/user/{$user}";
    $rtmp_url = "rtmp://{$user}.videocdn.scaleengine.net/{$app_name}/{$app_inst}/";
    $rtmpt_url = "rtmpt://{$user}.videocdn.scaleengine.net/{$app_name}/{$app_inst}/";
    $swf_url = "http://{$user}.embed.scaleengine.net/latest/jwplayer.swf";
    $hls_url = "http://{$user}.videocdn.scaleengine.net:1935/{$app_name}/{$app_inst}/{$video}/playlist.m3u8";
    
    //Set Default URLs
    if($jw_version == 6 || $jw_version == 7)
    {
        $js_url = "http://{$embed_base_url}/{$jw_version}.x/jwplayer.js";
        if($smil)
        {
            $hls_url = "http://{$user}.videocdn.scaleengine.net:1935/{$app_name}/{$app_inst}/{$smil}/playlist.m3u8";
            $smil_url = "http://{$user}.videocdn.scaleengine.net/{$app_name}/{$app_inst}/{$smil}/autogen.smil";
        }
        else
        {
            $smil_url = "rtmp://{$user}.videocdn.scaleengine.net/{$app_name}/{$app_inst}/";
        }
    }
    elseif($player != "videojs")
    {
        $js_url = "http://{$embed_base_url}/latest/jwplayer.min.js";
    }
    
    //Override the default rtmp location
    if(!empty($rtmp))
    {
        if(strpos($rtmp,'rtmp://') !== FALSE)
        {
            $rtmp_url =& $rtmp;
        }
        else
        {
            $rtmp_url = "rtmp://{$rtmp}";
        }
    }
    
    //Override the default rtsp location
    if(!empty($rtsp))
    {
        if(strpos($rtsp,'rtsp://') !== FALSE)
        {
            $rtsp_url =& $rtsp;
        }
        else
        {
            $rtsp_url = "rtsp://{$rtsp}";
        }
    }
    
    //Override the default swf location
    if(!empty($swf))
    {
        $swf_url =& $swf;
    }
    
    //Override the default js location
    if(!empty($js_player))
    {
        $js_url =& $js_player;
    }
    
    //Override the default playlist location
    if(!empty($swf))
    {
        $hls_url =& $playlist;
    }
    $ticket = null;
    
    if(isset($_SESSION['sevu_tickets'][$app_name][$video]))
    {
        $ticket =& $_SESSION['sevu_tickets'][$app_name][$video];
    }
    elseif(isset($_SESSION['sevu_tickets'][$app_name][$smil]))
    {
        $ticket =& $_SESSION['sevu_tickets'][$app_name][$smil];
    }
    else
    {
        //Order SEVU Ticket
        $sevu = new SEVU_API_WP;
        $vid_auth = $video;
        if($smil)
        {
            $vid_auth = "*";
        }
        
        $ticket =& $sevu->request_ticket($ip_restrict,$vid_auth,$app_name,$num_uses,$expire);
        if($smil)
        {
            $_SESSION['sevu_tickets'][$app_name]['smil'] = $ticket;
        }else
        {
            $_SESSION['sevu_tickets'][$app_name][$vid_auth] = $ticket;
        }
        
    }
    
    $amp = ($jw_version == 6 || $jw_version == 7)?'%26amp;':'&';
    
    $params = "?key={$ticket['key']}{$amp}pass={$ticket['pass']}";
    //echo 'You have been assigned a ticket: '.$ticket['key'];
    $hls_url .= $params;
    $rtmp_url .= $params;
    $smil_url .= $params;
    //$swf_url .= $params;
    
    ob_start();
    if($player == 'videojs')
    {
        $rtmp_url .= "&mp4:{$video}";
        $rtmpt_url .= "&mp4:{$video}";
        include_once($plugin_dir.'sevu_videojs.php');
    }
    elseif($jw_version == 6 || $jw_version == 7)
    {
        if(!$smil)
        {
            $smil_url .= "mp4:{$video}";
        }
        include_once($plugin_dir.'sevu_jw6.php');
    }
    else
    {
        include_once($plugin_dir.'sevu_embed.php');
    }
    
    $output = ob_get_contents();
    ob_end_clean();
    return $output;
}
//add the sevu shortcode
add_shortcode('sevu_embed','sevu_add_embed');

/*
 * Requests a SEVU ticket to be created
 * If a SEVU Ticket already exists in the session the existing ticket will be returned
 * 
 * @param Bool ip_restrict - Restrict ticket to an IP Addres
 * @param String video - path/to/video.mp4, * to allow viewing of any video
 * @param String app_name - name of the application
 * @param Int uses - # of times ticket may be used, 0 for unlimited uses
 * @param String expire - ISO 8601 or RFC 2822 formatted date, or as a relative time string ('+X units')
 *
 *  @return SEVU Ticket Parameter String - Key and Password for the ticket in GET Param format key=x&pass=x
 */
function request_sevu_params($atts)
{
    extract(shortcode_atts(array(
            'ip_restrict' => true,
            'video' => '*',
            'app_name' => '',
            'num_uses' => 99,
            'expire' => null,
        ),$atts)
    );
    
    if(isset($_SESSION['sevu_tickets'][$app_name][$video]))
    {
        $ticket = $_SESSION['sevu_tickets'][$app_name][$video];
    }
    elseif($_SESSION['sevu_tickets'][$app_name]['*'])
    {
        $ticket =& $_SESSION['sevu_tickets'][$app_name]['*'];
    }
    else
    {
        $sevu = new SEVU_API_WP;    
        $ticket =& $sevu->request_ticket($ip_restrict, $video, $app_name, $num_uses, $expire);
        $_SESSION['sevu_tickets'][$app_name][$video] = $ticket;
    }
    
    return "key={$ticket['key']}&pass={$ticket['pass']}";
}
add_shortcode('sevu_ticket','request_sevu_params');
?>
